from .dan_probes import danProbes
from .dan_detectors import danDetectors


def generate_response(client, model, prompt, max_tokens=150, n_generations=10):
    # model must be of of the OpenAI chat models like "gpt-3.5-turbo", "gpt-4" ..
    # for other models modify accordingly

    messages = [{"role": "user", "content": prompt}]
    response = client.chat.completions.create(
        model=model,
        messages=messages,
        temperature=0.7,
        top_p=1.0,
        stop=["#", ";"],
        max_tokens=max_tokens,
        n=n_generations,
    )

    return [c.message.content for c in response.choices]


# TODO: add support for multiple probe at a time
def dan_vulnerability_scanner(
    client,
    category=["DUDE"],
    model="gpt-3.5-turbo",
    prompt=None,
    response=None,
    context=None,
):
    # catogory shold be from the following:
    #         "Dan_11_0",
    #         "Dan_10_0",
    #         "Dan_9_0",
    #         "Dan_8_0",
    #         "Dan_7_0",
    #         "Dan_6_2",
    #         "Dan_6_0",
    #         "DUDE",
    #         "STAN",
    #         "DAN_Jailbreak",
    #         "AntiDAN",
    #         "ChatGPT_Developer_Mode_v2",
    #         "ChatGPT_Developer_Mode_RANTI",
    #         "ChatGPT_Image_Markdown",
    #         "Ablation_Dan_11_0",
    #         "AutoDANProbe",
    #         "DanInTheWild",
    #         "DanInTheWildMini",

    category = category[0]
    prompt_detector_dict = danProbes(category).result_dict

    result_dict = prompt_detector_dict
    m_prompts = result_dict["prompts"]
    detector_names = [
        detector.split(".")[-1] for detector in result_dict["recommended_detector"]
    ]

    m_response = []
    for m_prompt in m_prompts:
        model_response = generate_response(client, model, m_prompt, n_generations=10)
        m_response.extend(model_response)

    final_score = []
    score_dict = {}
    for detector in detector_names:
        detector_score = danDetectors(
            detector_name=detector, response=m_response
        ).detector_score
        final_score.extend(detector_score)
        score_dict[detector] = {
            "passed_cases": sum(detector_score),
            "out_of": len(detector_score),
        }

    score = sum(final_score) / len(final_score)

    results = {
        "category": category,
        "is_passed": score == 1.0,
        "score": score,
        "detectors_score": score_dict,
    }

    return results
